pub trait Handler: AsRcAny {
// Required methods
fn set_handler_healthy(self: Rc<Self>);
fn set_handler_unhealthy(self: Rc<Self>, msg: &str);
fn get_name(&self) -> &'static str;
fn interest(&self) -> Vec<InputEventType>;
}Required Methods
fn set_handler_healthy(self: Rc<Self>)
fn set_handler_unhealthy(self: Rc<Self>, msg: &str)
Sourcefn interest(&self) -> Vec<InputEventType>
fn interest(&self) -> Vec<InputEventType>
Returns the types of input events this handler is interested in.
Implementors
impl Handler for DeadKeysHandler
This trait implementation allows the Handler to be hooked up into the input pipeline.